@@ -1,8 +1,8 @@
 import argparse
-import initHandler
-import subjectHandler
-import sessionHandler
-import scheduleHandler
+from nwborglab import initHandler
+from nwborglab import subjectHandler
+from nwborglab import sessionHandler
+from nwborglab import scheduleHandler
 
 def main():
     parser = argparse.ArgumentParser('nwborglab','Takes in parameters for nwborg to run')
